@@ -12,8 +12,8 @@ cd ..
 
 
 for language in $ALL_LANGUAGES; do
-    cp po/$language.po qtomweather/qt-qml/po/locale/$language
-#   cp po/$language.po qtomweather/qt-qml/po/$language.po
+    cp po/$language.po meecast/qt-qml/po/locale/$language
+#   cp po/$language.po meecast/qt-qml/po/$language.po
 done
 
 
